# pysolorie

[![Actions Status](https://github.com/aaghamohammadi/pysolorie/actions/workflows/quality_checks.yml/badge.svg?branch=main)](https://github.com/aaghamohammadi/pysolorie/actions)


Orientation Analysis of Solar Panel
